import { Sequelize, DataTypes, Model, Optional } from "sequelize";
import BoatType from "./BoatType";

interface BoatAttributes {
  id: string;
  name: string;
  status: boolean;
}

export interface BoatAttributesInput extends Optional<BoatAttributes, "id"> {}

class Boat
  extends Model<BoatAttributes, BoatAttributesInput>
  implements BoatAttributes
{
  declare id: string;
  declare name: string;
  declare status: boolean;

  declare readonly createdAt: Date;
  declare readonly updatedAt: Date;
}

export const initBoat = async (sequelizeConnection: Sequelize) => {
  Boat.init(
    {
      id: {
        type: DataTypes.UUID,
        defaultValue: DataTypes.UUIDV4,
        primaryKey: true,
        allowNull: false,
      },
      name: {
        type: new DataTypes.STRING(),
        allowNull: false,
      },
      status: {
        type: DataTypes.BOOLEAN,
        allowNull: false,
      },
    },
    {
      tableName: "boat",
      sequelize: sequelizeConnection,
    }
  );
  return Boat;
};

export default Boat;
